@@ -94,12 +94,12 @@ def get_available(command="dumpavail"):
     "Return an apt_pkg object that represents the parsed list of packages."
     
     # This originally ran the apt-cache command as a pipe to
-    # ParseTagFile as in:
+    # TagFile as in:
     #  command = "apt-cache dumpavail"
     #  packages_pipe = perform.execute(command, noquiet=True, pipe=True)
-    #  avail = apt_pkg.ParseTagFile(packages_pipe)
+    #  avail = apt_pkg.TagFile(packages_pipe)
     #    
-    # But as in Bug#366678 ParseTagFile no longer works in a pipe
+    # But as in Bug#366678 TagFile no longer works in a pipe
     # because of changes to apt_pkg by Michael Vogt. He supplied
     # suggested fixes, but they were not tested and I've not had
     # a chance to understand the new APT package for Python. So put
@@ -117,7 +117,7 @@ def get_available(command="dumpavail"):
     command = "cat /var/lib/dpkg/status >> " + tmpcache
     perform.execute(command)
     # 090501 End
-    avail = apt_pkg.ParseTagFile(file(tmpcache))
+    avail = apt_pkg.TagFile(file(tmpcache))
     if os.path.exists(tmpcache): os.remove(tmpcache)
     return(avail)
 
@@ -134,14 +134,14 @@ def do_dependents(package):
     #
     # Check for information in the Available list
     #
-    while avail.Step():
-        nam = avail.Section.get("Package")
+    for section in avail:
+        nam = section.get("Package")
         if (nam in pkgs):
-            dep = avail.Section.get("Depends")
-            sug = avail.Section.get("Suggests")
-            rec = avail.Section.get("Recommends")
-            con = avail.Section.get("Conflicts")
-            rep = avail.Section.get("Replaces")
+            dep = section.get("Depends")
+            sug = section.get("Suggests")
+            rec = section.get("Recommends")
+            con = section.get("Conflicts")
+            rep = section.get("Replaces")
             if not dep: dep = ""
             if not sug: sug = ""
             if not rec: rec = ""
@@ -209,9 +209,9 @@ def do_describe(packages):
     #  apt-cache dumpavail > /tmp/avail
     #  dpkg --update-avail /tmp/avail
     #
-    # avail  = apt_pkg.ParseTagFile(open("/var/cache/apt/available","r"));
-    # avail  = apt_pkg.ParseTagFile(open("/var/cache/apt/pkgcache.bin","r"));
-    # avail  = apt_pkg.ParseTagFile(open("/var/lib/dpkg/available","r"))
+    # avail  = apt_pkg.TagFile(open("/var/cache/apt/available","r"));
+    # avail  = apt_pkg.TagFile(open("/var/cache/apt/pkgcache.bin","r"));
+    # avail  = apt_pkg.TagFile(open("/var/lib/dpkg/available","r"))
     #
     # Simplest solution seems to be to pipe details of all packages
     # from apt-cache (which needs sudo). 23 Aug 2003.
@@ -260,10 +260,10 @@ def do_describe(packages):
     #
     # Check for information in the Available list
     #
-    while avail.Step():
-        if (avail.Section.get("Package") in packages):
-            package_name = avail.Section.get("Package")
-            package_description = avail.Section.get("Description")
+    for section in avail:
+        if (section.get("Package") in packages):
+            package_name = section.get("Package")
+            package_description = section.get("Description")
             if not describe_list.has_key(package_name):
                 describe_list[package_name] = package_description
     # Bug fix for Bug#366678 Part 2 - not working yet???
@@ -600,10 +600,10 @@ def do_install_suggest(packages, type, noauth=""):
     #
     # Check for information in the Available list
     #
-    while avail.Step():
-        if (avail.Section.get("Package") in packages):
-            sug = avail.Section.get("Suggests")
-            rec = avail.Section.get("Recommends")
+    for section in avail:
+        if (section.get("Package") in packages):
+            sug = section.get("Suggests")
+            rec = section.get("Recommends")
             if type == "Suggests" or type == "Both":
                 if sug: suggest_list = suggest_list+" "+sug
             if type == "Recommends" or type == "Both":
@@ -640,8 +640,16 @@ def do_install_suggest(packages, type, noauth=""):
     #else:
     #    cont = ""
     #if cont == "" or cont == "Y" or cont == "y" or cont == "yes":
-    command = "apt-get %s --show-upgraded install " % noauth \
-              + perform.concat(packages) + suggest_list
+
+    # 100224 Bug #402598 Use aptitude -r to get the recursive
+    # recommends installed, rather than going just one level.
+
+    if type == "Recommends":
+        command = "aptitude %s -r --show-deps --show-versions install " % noauth \
+            + perform.concat(packages) + suggest_list
+    else:
+        command = "apt-get %s --show-upgraded install " % noauth \
+            + perform.concat(packages) + suggest_list
     perform.execute(command, root=1)
 
 #-----------------------------------------------------------------------
@@ -652,17 +660,17 @@ def do_install_suggest(packages, type, noauth=""):
 def do_listsections():
     avail = get_available()
     sections = []
-    while avail.Step():
-        s = avail.Section.get("Section")
+    for section in avail:
+        s = section.get("Section")
         if s not in sections:
             sections.append(s)
     print "\n".join(sections)
 
 def do_listsection(pattern):
     avail = get_available()
-    while avail.Step():
-        if (pattern == avail.Section.get("Section")):
-            print avail.Section.get("Package")
+    for section in avail:
+        if (pattern == section.get("Section")):
+            print section.get("Package")
 
 #------------------------------------------------------------------------
 #
@@ -757,18 +765,18 @@ def map_sources(packages):
     Note that the source could include a version number.
     Only replace with source if package exists (Bug#295455).
 """
-    Parse = apt_pkg.ParseTagFile(open("/var/lib/dpkg/available","r"))
+    tagfile = apt_pkg.TagFile(open("/var/lib/dpkg/available","r"))
     sources = []
-    while Parse.Step():
+    for section in tagfile:
         # May want to look to terminate as soon as all packages
         # have been found - to be more efficient
-        if Parse.Section.get("Package") in packages:
-            if Parse.Section.get("Source"):
-                #pkgname = Parse.Section.get("Source").split()[0]
-                pkgname = Parse.Section.get("Source")
-                sources += [[pkgname, Parse.Section.get("Package")]]
+        if section.get("Package") in packages:
+            if section.get("Source"):
+                #pkgname = section.get("Source").split()[0]
+                pkgname = section.get("Source")
+                sources += [[pkgname, section.get("Package")]]
             else:
-                sources += [[Parse.Section.get("Package"), Parse.Section.get("Package")]]
+                sources += [[section.get("Package"), section.get("Package")]]
     return sources
 
 def do_news(packages):
@@ -835,7 +843,7 @@ def do_news(packages):
 #     #
 #     command = "apt-cache show " + package
 #     packages_pipe = perform.execute(command, noquiet=True, pipe=True)
-#     Parse = apt_pkg.ParseTagFile(packages_pipe)
+#     Parse = apt_pkg.TagFile(packages_pipe)
 #     version = '0'
 #     filename = ''
 #     while Parse.Step():
@@ -966,6 +974,8 @@ def do_newupgrades(install=False):
             print "="*74
             do_install(new_upgrades)
 
+# 100519 No longer used - user apt-get's --auto-remove instead
+
 def do_removedepend(pkg, purge=False):
     print "Checking dependencies. Please wait..."
     toremove = pkg
@@ -1002,7 +1012,7 @@ def do_size(packages, size):
     # Work with the list of installed packages
     # (I think status has more than installed?)
     #
-    status = apt_pkg.ParseTagFile(open("/var/lib/dpkg/status","r"));
+    status = apt_pkg.TagFile(open("/var/lib/dpkg/status","r"));
     #
     # Initialise the sizes dictionary.
     #
@@ -1011,11 +1021,11 @@ def do_size(packages, size):
     #
     # Check for information in the Status list
     #
-    while status.Step():
-        if not packages or status.Section.get("Package") in packages:
-            package_name   = status.Section.get("Package")
-            package_size   = status.Section.get("Installed-Size")
-            package_status = re.split(" ", status.Section.get("Status"))[2]
+    for section in status:
+        if not packages or section.get("Package") in packages:
+            package_name   = section.get("Package")
+            package_size   = section.get("Installed-Size")
+            package_status = re.split(" ", section.get("Status"))[2]
             if package_size and int(package_size) > size:
                 if not size_list.has_key(package_name):
                     size_list[package_name] = package_size
@@ -1489,11 +1499,11 @@ def do_recdownload(packages):
         Author: Juanjo Alvarez <juanjux@yahoo.es>"""
 
     def get_deps(package):
-        Parse = apt_pkg.ParseTagFile(open("/var/lib/dpkg/available","r"))
+        tagfile = apt_pkg.TagFile(open("/var/lib/dpkg/available","r"))
         deplist = []
-        while Parse.Step():
-            if Parse.Section.get("Package")==package:
-                deplist = apt_pkg.ParseDepends(Parse.Section.get("Depends",""))
+        for section in tagfile:
+            if section.get("Package")==package:
+                deplist = apt_pkg.parse_depends(section.get("Depends",""))
                 break
         realdeplist = []
         if deplist != []:
