@@ -773,7 +773,9 @@ def select_command(command, args, verbose, teaching):
 
     elif command == "purgedepend":
         if requires_one_arg(command, args, "a single package"):
-            commands.do_removedepend(args[1], purge = True)
+            # Bug#579419 - this is more efficient than do_removedepend 
+            perform.execute("apt-get remove --purge --auto-remove " + args[1], root=1)
+            # commands.do_removedepend(args[1], purge = True)
 
     elif command == "purgeorphans":
         #
@@ -853,7 +855,9 @@ def select_command(command, args, verbose, teaching):
     elif command == "removedepend":
         if requires_one_arg(command, args, "a single package"):
             #print changes.get_dependees("libclan2-mikmod")
-            commands.do_removedepend(args[1])
+            # Bug#579419 - this is more efficient than do_removedepend 
+            perform.execute("apt-get remove --auto-remove " + args[1], root=1)
+            #commands.do_removedepend(args[1])
             
     elif command == "removeorphans":
         if requires_no_args(command, args):
@@ -1052,6 +1056,7 @@ def select_command(command, args, verbose, teaching):
         print "Perhaps it is not yet implemented or you misspelt the command."
         print "Try `wajig help' for further information."
         print "Try `wajig list-commands' for list of all commands."
+
     changes.finish_log()
 
 #------------------------------------------------------------------------
